@@ -1,3 +1,5 @@
+DELETE FROM cart
+DELETE FROM cart_items
 INSERT INTO cart (id,shopper,type,name,description) VALUES ('11111111-1111-1111-1111-111111111111','11111111-1111-1111-1111-111111111111',0,'Cart 1', 'Test Temp Cart 1')
 INSERT INTO cart (id,shopper,type,name,description) VALUES ('22222222-2222-2222-2222-222222222222','11111111-1111-1111-1111-111111111111',0,'Cart 2', 'Test Temp Cart 2')
 INSERT INTO cart (id,shopper,type,name,description) VALUES ('33333333-3333-3333-3333-333333333333','33333333-3333-3333-3333-333333333333',1,'Cart 3', 'Saved Cart 1')
